@@ -24,10 +24,10 @@ func registerCmd(ctx *config.RunContext) *cobra.Command {
 			var msg string
 			var isRegenerate bool
 
-			if _, ok := ctx.Config.Credentials[ctx.Config.PricingAPIEndpoint]; ok {
+			if ctx.Config.Credentials.APIKey != "" {
 
 				isRegenerate = true
-				fmt.Printf("You already have an Infracost API key saved in %s.\n", config.CredentialsFilePath())
+				fmt.Printf("You already have an Infracost API key saved in %s\n", config.CredentialsFilePath())
 
 				status, err := promptGenerateNewKey()
 				if err != nil {
@@ -92,9 +92,8 @@ func registerCmd(ctx *config.RunContext) *cobra.Command {
 				}
 			}
 
-			ctx.Config.Credentials[ctx.Config.PricingAPIEndpoint] = config.CredentialsProfileSpec{
-				APIKey: r.APIKey,
-			}
+			ctx.Config.Credentials.APIKey = r.APIKey
+			ctx.Config.Credentials.PricingAPIEndpoint = ctx.Config.PricingAPIEndpoint
 
 			err = ctx.Config.Credentials.Save()
 			if err != nil {
